function roi_count(fnm, roi)
%Report region of interest descriptives for image
% fnm: continuous image
% roi: atlas image with discrete regions
%Example
% roi_count %useGUI
% roi_count('rthreshZ4V_5VD-qzhoActiv.nii', 'natbrainlab.nii');

if ~exist('fnm','var')
	fnm = spm_select(1,'image','Select continuous imagee'); 
end
if ~exist('roi','var')
	roi = spm_select(1,'image','Select atlas regions of interest'); 
end
rhdr = spm_vol(roi);
rimg = spm_read_vols(rhdr);
hdr = spm_vol(fnm);
img = spm_read_vols(hdr);
if (size(img, 1) ~= size(rimg, 1)) ||  (size(img, 2) ~= size(rimg, 2)) || (size(img, 3) ~= size(rimg, 3)) 
    fprintf('Images do  not match: reslicing\n');
    [rhdr, rimg] = nii_reslice_target(rhdr, rimg, hdr, 0);
end
nroi = max(rimg(:));
fprintf('%d regions in %s\n', nroi, roi);
fprintf('region\tnZero\tnPos\tnNeg\tnNotFinite\tmn\n');
for r = 0 : nroi
    v = img(rimg(:)== r);
    if isempty(v), continue; end;
    n = numel(v);
    nZero = numel(v(v == 0) );
    if n == nZero, continue; end;
    
    mn = mean(v(:));
    nZero = numel(v(v == 0) );
    nPos = numel(v(v > 0) );
    nNeg= numel(v(v < 0) );
    nNotFinite = numel(v(~isfinite(v)) );     
    fprintf('%d\t%d\t%d\t%d\t%d\t%g\n', r, nZero, nPos, nNeg, nNotFinite, mn); 
end



